@@ -17,7 +17,8 @@
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-from typing import Union
+import re
+from typing import Union, BinaryIO
 
 import pyrogram
 from pyrogram.api import functions, types
@@ -29,7 +30,7 @@ class SendAnimation(BaseClient):
     def send_animation(
         self,
         chat_id: Union[int, str],
-        animation: str,
+        animation: Union[str, BinaryIO],
         file_ref: str = None,
         caption: str = "",
         unsave: bool = False,
@@ -37,7 +38,8 @@ class SendAnimation(BaseClient):
         duration: int = 0,
         width: int = 0,
         height: int = 0,
-        thumb: str = None,
+        thumb: Union[str, BinaryIO] = None,
+        file_name: str = None,
         disable_notification: bool = None,
         reply_to_message_id: int = None,
         schedule_date: int = None,
@@ -58,11 +60,12 @@ class SendAnimation(BaseClient):
                 For your personal cloud (Saved Messages) you can simply use "me" or "self".
                 For a contact that exists in your Telegram address book you can use his phone number (str).
 
-            animation (``str``):
+            animation (``str`` | ``BinaryIO``):
                 Animation to send.
                 Pass a file_id as string to send an animation that exists on the Telegram servers,
-                pass an HTTP URL as a string for Telegram to get an animation from the Internet, or
-                pass a file path as string to upload a new animation that exists on your local machine.
+                pass an HTTP URL as a string for Telegram to get an animation from the Internet,
+                pass a file path as string to upload a new animation that exists on your local machine, or
+                pass a binary file-like object with its attribute ".name" set for in-memory uploads.
 
             file_ref (``str``, *optional*):
                 A valid file reference obtained by a recently fetched media message.
@@ -91,12 +94,16 @@ class SendAnimation(BaseClient):
             height (``int``, *optional*):
                 Animation height.
 
-            thumb (``str``, *optional*):
+            thumb (``str`` | ``BinaryIO``, *optional*):
                 Thumbnail of the animation file sent.
                 The thumbnail should be in JPEG format and less than 200 KB in size.
                 A thumbnail's width and height should not exceed 320 pixels.
                 Thumbnails can't be reused and can be only uploaded as a new file.
 
+            file_name (``str``, *optional*):
+                File name of the animation sent.
+                Defaults to file's path basename.
+
             disable_notification (``bool``, *optional*):
                 Sends the message silently.
                 Users will receive a notification with no sound.
@@ -158,11 +165,36 @@ class SendAnimation(BaseClient):
         file = None
 
         try:
-            if os.path.exists(animation):
-                thumb = None if thumb is None else self.save_file(thumb)
+            if isinstance(animation, str):
+                if os.path.isfile(animation):
+                    thumb = self.save_file(thumb)
+                    file = self.save_file(animation, progress=progress, progress_args=progress_args)
+                    media = types.InputMediaUploadedDocument(
+                        mime_type=self.guess_mime_type(animation) or "video/mp4",
+                        file=file,
+                        thumb=thumb,
+                        attributes=[
+                            types.DocumentAttributeVideo(
+                                supports_streaming=True,
+                                duration=duration,
+                                w=width,
+                                h=height
+                            ),
+                            types.DocumentAttributeFilename(file_name=file_name or os.path.basename(animation)),
+                            types.DocumentAttributeAnimated()
+                        ]
+                    )
+                elif re.match("^https?://", animation):
+                    media = types.InputMediaDocumentExternal(
+                        url=animation
+                    )
+                else:
+                    media = utils.get_input_media_from_file_id(animation, file_ref, 10)
+            else:
+                thumb = self.save_file(thumb)
                 file = self.save_file(animation, progress=progress, progress_args=progress_args)
                 media = types.InputMediaUploadedDocument(
-                    mime_type=self.guess_mime_type(animation) or "video/mp4",
+                    mime_type=self.guess_mime_type(animation.name) or "video/mp4",
                     file=file,
                     thumb=thumb,
                     attributes=[
@@ -172,16 +204,10 @@ class SendAnimation(BaseClient):
                             w=width,
                             h=height
                         ),
-                        types.DocumentAttributeFilename(file_name=os.path.basename(animation)),
+                        types.DocumentAttributeFilename(file_name=animation.name),
                         types.DocumentAttributeAnimated()
                     ]
                 )
-            elif animation.startswith("http"):
-                media = types.InputMediaDocumentExternal(
-                    url=animation
-                )
-            else:
-                media = utils.get_input_media_from_file_id(animation, file_ref, 10)
 
             while True:
                 try:
